# DrivAerNet++

## Quick Start

### 1. Download Raw Data

Please have a look at https://github.com/Mohamedelrefaie/DrivAerNet to download the data.

### 2. Preprocess the Data

To preprocess the datasets, please use the following script [preprocessing.py](./preprocessing.py)
